"use strict";
// Copyright (c) Vidar Tonaas Fauske.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("@jupyter-widgets/base");
const chromabar_1 = require("chromabar");
const d3_selection_1 = require("d3-selection");
const version_1 = require("../version");
class ColorMapEditorModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign({}, super.defaults(), { _model_name: ColorMapEditorModel.model_name, _model_module: ColorMapEditorModel.model_module, _model_module_version: ColorMapEditorModel.model_module_version, _view_name: ColorMapEditorModel.view_name, _view_module: ColorMapEditorModel.view_module, _view_module_version: ColorMapEditorModel.view_module_version, colormap: null, orientation: 'horizontal', length: 300, breadth: 30, padding: 5, border_thickness: 1 });
    }
    initialize(attributes, options) {
        super.initialize(attributes, options);
        this.setupListeners();
    }
    setupListeners() {
        // register listener for current child value
        const childAttrName = 'colormap';
        var curValue = this.get(childAttrName);
        if (curValue) {
            this.listenTo(curValue, 'change', this.onChildChanged.bind(this));
            this.listenTo(curValue, 'childchange', this.onChildChanged.bind(this));
        }
        // make sure to (un)hook listeners when child points to new object
        this.on(`change:${childAttrName}`, (model, value) => {
            var prevModel = this.previous(childAttrName);
            var currModel = value;
            if (prevModel) {
                this.stopListening(prevModel);
            }
            if (currModel) {
                this.listenTo(currModel, 'change', this.onChildChanged.bind(this));
                this.listenTo(currModel, 'childchange', this.onChildChanged.bind(this));
            }
        }, this);
    }
    onChildChanged(model) {
        // Propagate up hierarchy:
        this.trigger('childchange', this);
    }
}
ColorMapEditorModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers, { colormap: { deserialize: base_1.unpack_models } });
ColorMapEditorModel.model_name = 'ColorMapEditorModel';
ColorMapEditorModel.model_module = version_1.moduleName;
ColorMapEditorModel.model_module_version = version_1.version;
ColorMapEditorModel.view_name = 'ColorMapEditorView';
ColorMapEditorModel.view_module = version_1.moduleName;
ColorMapEditorModel.view_module_version = version_1.version;
exports.ColorMapEditorModel = ColorMapEditorModel;
class ColorMapEditorView extends base_1.DOMWidgetView {
    render() {
        const cmModel = this.model.get('colormap');
        this.editorFn = chromabar_1.chromaEditor(cmModel.obj)
            .onUpdate((save) => {
            // Sync back all changes to both server and here
            cmModel.syncToModel({});
            if (save) {
                cmModel.save_changes();
            }
        });
        this.onChange();
        this.model.on('change', this.tick, this);
        this.model.on('childchange', this.tick, this);
    }
    tick() {
        requestAnimationFrame(this.onChange.bind(this));
    }
    onChange() {
        this.editorFn
            .orientation(this.model.get('orientation'))
            .barLength(this.model.get('length'))
            .breadth(this.model.get('breadth'))
            .padding(this.model.get('padding'))
            .borderThickness(this.model.get('border_thickness'));
        let svg = d3_selection_1.select(this.el)
            .selectAll('svg.jupyterColorbar').data([null]);
        svg = svg.merge(svg.enter().append('svg')
            .attr('class', 'jupyterColorbar'));
        svg
            .call(this.editorFn);
    }
}
exports.ColorMapEditorView = ColorMapEditorView;
//# sourceMappingURL=editor.js.map