"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
const d3_scale_1 = require("d3-scale");
const d3Interpolate = require("d3-interpolate");
const scale_1 = require("./scale");
/**
 * Find the name of the d3-interpolate function
 */
function interpolatorName(fun) {
    for (let key of Object.keys(d3Interpolate)) {
        if (d3Interpolate[key] === fun) {
            return key;
        }
    }
    throw ReferenceError(`Cannot find name of interpolator ${fun}`);
}
/**
 * A widget model of a continuous scale
 */
class ContinuousScaleModel extends scale_1.ScaleModel {
    defaults() {
        return Object.assign({}, super.defaults(), { domain: [0, 1], range: [0, 1], interpolator: 'interpolate', clamp: false });
    }
    createPropertiesArrays() {
        super.createPropertiesArrays();
        this.simpleProperties.push('domain', 'range', 'clamp');
    }
    /**
     * Sync the model properties to the d3 object.
     */
    syncToObject() {
        super.syncToObject();
        let interpolatorName = this.get('interpolator') || 'interpolate';
        let interpolator = d3Interpolate[interpolatorName];
        this.obj.interpolate(interpolator);
    }
    /**
     * Synt the d3 object properties to the model.
     */
    syncToModel(toSet) {
        let interpolator = this.obj.interpolate();
        toSet['interpolator'] = interpolatorName(interpolator);
        super.syncToModel(toSet);
    }
}
ContinuousScaleModel.serializers = Object.assign({}, scale_1.ScaleModel.serializers);
exports.ContinuousScaleModel = ContinuousScaleModel;
/**
 * A widget model of a linear scale
 */
class LinearScaleModel extends ContinuousScaleModel {
    /**
     * Create the wrapped d3-scale scaleLinear object
     */
    constructObject() {
        return d3_scale_1.scaleLinear();
    }
}
LinearScaleModel.serializers = Object.assign({}, ContinuousScaleModel.serializers);
LinearScaleModel.model_name = 'LinearScaleModel';
exports.LinearScaleModel = LinearScaleModel;
/**
 * A widget model of a linear scale
 */
class LogScaleModel extends ContinuousScaleModel {
    defaults() {
        return Object.assign({}, super.defaults(), { base: 10, domain: [1, 10] });
    }
    createPropertiesArrays() {
        super.createPropertiesArrays();
        this.simpleProperties.push('base');
    }
    /**
     * Create the wrapped d3-scale scaleLinear object
     */
    constructObject() {
        return d3_scale_1.scaleLog();
    }
}
LogScaleModel.serializers = Object.assign({}, ContinuousScaleModel.serializers);
LogScaleModel.model_name = 'LogScaleModel';
exports.LogScaleModel = LogScaleModel;
/**
 * A widget model of a linear scale
 */
class PowScaleModel extends ContinuousScaleModel {
    defaults() {
        this.constructor;
        return Object.assign({}, super.defaults(), { exponent: 1 });
    }
    createPropertiesArrays() {
        super.createPropertiesArrays();
        this.simpleProperties.push('exponent');
    }
    /**
     * Create the wrapped d3-scale scaleLinear object
     */
    constructObject() {
        return d3_scale_1.scalePow();
    }
}
PowScaleModel.serializers = Object.assign({}, ContinuousScaleModel.serializers);
PowScaleModel.model_name = 'PowScaleModel';
exports.PowScaleModel = PowScaleModel;
//# sourceMappingURL=continuous.js.map