import { WidgetModel } from '@jupyter-widgets/base';
import { ObjectHash } from 'backbone';
import { ISerializers, IDataWriteBack } from 'jupyter-dataserializers';
import { DataModel } from 'jupyter-datawidgets/lib/base';
import ndarray = require('ndarray');
/**
 * Create new ndarray, with default attributes taken from another
 *
 * @param {ndarray.NDArray} array
 * @returns {ndarray.NDArray}
 */
export declare function arrayFrom(array: ndarray, dtype?: ndarray.DataType | null, shape?: number[] | null): ndarray;
/**
 * Scaled array model.
 *
 * This model provides a scaled version of an array, that is
 * automatically recomputed when either the array or the scale
 * changes.
 *
 * @export
 * @class ScaledArrayModel
 * @extends {DataModel}
 */
export declare class ScaledArrayModel extends DataModel implements IDataWriteBack {
    defaults(): any;
    /**
     * (Re-)compute the scaledData data.
     *
     * @returns {void}
     * @memberof ScaledArrayModel
     */
    computeScaledData(options?: any): void;
    /**
     * Initialize the model
     *
     * @param {Backbone.ObjectHash} attributes
     * @param {{model_id: string; comm?: any; widget_manager: any; }} options
     * @memberof ScaledArrayModel
     */
    initialize(attributes: ObjectHash, options: {
        model_id: string;
        comm?: any;
        widget_manager: any;
    }): void;
    /**
     * Sets up any relevant event listeners after the object has been initialized,
     * but before the initPromise is resolved.
     *
     * @memberof ScaledArrayModel
     */
    setupListeners(): void;
    getNDArray(key?: string): ndarray | null;
    canWriteBack(key?: string): boolean;
    setNDArray(array: ndarray | null, key?: string, options?: any): void;
    /**
     * Callback for when the source data changes.
     *
     * @param {WidgetModel} model
     * @memberof ScaledArrayModel
     */
    protected onChange(model: WidgetModel, options?: any): void;
    /**
     * Whether scaledData has the incorrect shape or type.
     *
     * @protected
     * @returns {boolean}
     * @memberof ScaledArrayModel
     */
    protected arrayMismatch(): boolean;
    /**
     * Get what the dtype of the scaled data *should* be
     */
    protected scaledDtype(): ndarray.DataType | null;
    /**
     * Get what the shape of the scaled data *should* be
     */
    protected scaledShape(): number[] | null;
    /**
     * A promise that resolves once the model has finished its initialization.
     *
     * @type {Promise<void>}
     * @memberof ScaledArrayModel
     */
    initPromise: Promise<void>;
    static serializers: ISerializers;
    static model_name: string;
    static model_module: any;
    static model_module_version: any;
}
