import { WidgetModel } from '@jupyter-widgets/base';
import { ObjectHash } from 'backbone';
import { ISerializers } from 'jupyter-dataserializers';
/**
 * Scaled value model.
 *
 * This model provides a scaled value, that is automatically recomputed when
 * either the input value or the scale changes.
 */
export declare class ScaledValueModel extends WidgetModel {
    defaults(): any;
    /**
     * (Re-)compute the output.
     *
     * @returns {void}
     * @memberof ScaledArrayModel
     */
    computeScaledValue(options?: any): void;
    /**
     * Initialize the model
     *
     * @param {Backbone.ObjectHash} attributes
     * @param {{model_id: string; comm?: any; widget_manager: any; }} options
     * @memberof ScaledArrayModel
     */
    initialize(attributes: ObjectHash, options: {
        model_id: string;
        comm?: any;
        widget_manager: any;
    }): void;
    /**
     * Sets up any relevant event listeners after the object has been initialized,
     * but before the initPromise is resolved.
     *
     * @memberof ScaledArrayModel
     */
    setupListeners(): void;
    /**
     * Callback for when the source input changes.
     *
     * @param {WidgetModel} model
     * @memberof ScaledArrayModel
     */
    protected onChange(model: WidgetModel, options?: any): void;
    /**
     * A promise that resolves once the model has finished its initialization.
     *
     * @type {Promise<void>}
     * @memberof ScaledArrayModel
     */
    initPromise: Promise<void>;
    static serializers: ISerializers;
    static model_name: string;
    static model_module: any;
    static model_module_version: any;
    static view_name: null;
    static view_module: null;
    static view_module_version: any;
}
